==> haskell-tf-random-0.5-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tf-random.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tf-random
version: 0.5
id: tf-random-0.5-I39p3qgWMzeLwkvBknVuZq
key: tf-random-0.5-I39p3qgWMzeLwkvBknVuZq
license: BSD-3-Clause
maintainer: Michał Pałka <michal.palka@chalmers.se>
author: Michał Pałka <michal.palka@chalmers.se>
synopsis: High-quality splittable pseudorandom number generator
description:
    This package contains an implementation of a high-quality splittable pseudorandom number generator. The generator is based on a cryptographic hash function built on top of the ThreeFish block cipher. See the paper /Splittable Pseudorandom Number Generators Using Cryptographic Hashing/ by Claessen, Pałka for details and the rationale of the design.
    .
    The package provides the following:
    .
    * A splittable PRNG that implements the standard '\''System.Random.RandomGen'\'' class.
    .
    * The generator also implements an alternative version of the '\''System.Random.TF.Gen.RandomGen'\'' class (exported from "System.Random.TF.Gen"), which requires the generator to return pseudorandom integers from the full 32-bit range, and contains an n-way split function.
    .
    * An alternative version of the @Random@ class is provided, which is linked to the new @RandomGen@ class, together with @Random@ instances for some integral types.
    .
    * Two functions for initialising the generator with a non-deterministic seed: one using the system time, and one using the @\/dev\/urandom@ UNIX special file.
    .
    The package uses an adapted version of the reference C implementation of ThreeFish from the reference package of the Skein hash function (<https://www.schneier.com/skein.html>), originally written by Doug Whiting.
    .
    Please note that even though the generator provides very high-quality pseudorandom numbers, it has not been designed with cryptographic applications in mind.
category: Random
abi: 687f5f41114c24feb97c02bc0e8d404d
exposed: True
exposed-modules:
    System.Random.TF System.Random.TF.Gen System.Random.TF.Init
    System.Random.TF.Instances
import-dirs: /usr/lib/ghc-8.4.3/site-local/tf-random-0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/tf-random-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tf-random-0.5
hs-libraries: HStf-random-0.5-I39p3qgWMzeLwkvBknVuZq
depends:
    base-4.11.1.0 primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV time-1.8.0.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
haddock-interfaces: /usr/share/doc/haskell-tf-random/html/tf-random.haddock
haddock-html: /usr/share/doc/haskell-tf-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tf-random-0.5-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tf-random.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tf-random
version: 0.5
id: tf-random-0.5-DGXDH2T2OVbHHRLZ895CUL
key: tf-random-0.5-DGXDH2T2OVbHHRLZ895CUL
license: BSD-3-Clause
maintainer: Michał Pałka <michal.palka@chalmers.se>
author: Michał Pałka <michal.palka@chalmers.se>
synopsis: High-quality splittable pseudorandom number generator
description:
    This package contains an implementation of a high-quality splittable pseudorandom number generator. The generator is based on a cryptographic hash function built on top of the ThreeFish block cipher. See the paper /Splittable Pseudorandom Number Generators Using Cryptographic Hashing/ by Claessen, Pałka for details and the rationale of the design.
    .
    The package provides the following:
    .
    * A splittable PRNG that implements the standard '\''System.Random.RandomGen'\'' class.
    .
    * The generator also implements an alternative version of the '\''System.Random.TF.Gen.RandomGen'\'' class (exported from "System.Random.TF.Gen"), which requires the generator to return pseudorandom integers from the full 32-bit range, and contains an n-way split function.
    .
    * An alternative version of the @Random@ class is provided, which is linked to the new @RandomGen@ class, together with @Random@ instances for some integral types.
    .
    * Two functions for initialising the generator with a non-deterministic seed: one using the system time, and one using the @\/dev\/urandom@ UNIX special file.
    .
    The package uses an adapted version of the reference C implementation of ThreeFish from the reference package of the Skein hash function (<https://www.schneier.com/skein.html>), originally written by Doug Whiting.
    .
    Please note that even though the generator provides very high-quality pseudorandom numbers, it has not been designed with cryptographic applications in mind.
category: Random
abi: 33719bcc8fdb06cd40feb6cd2b1f72f1
exposed: True
exposed-modules:
    System.Random.TF System.Random.TF.Gen System.Random.TF.Init
    System.Random.TF.Instances
import-dirs: /usr/lib/ghc-8.6.1/site-local/tf-random-0.5
library-dirs: /usr/lib/ghc-8.6.1/site-local/tf-random-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/tf-random-0.5
hs-libraries: HStf-random-0.5-DGXDH2T2OVbHHRLZ895CUL
depends:
    base-4.12.0.0 primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    random-1.1-3ypV4EIycgb35PKjTYYr5q time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-tf-random/html/tf-random.haddock
haddock-html: /usr/share/doc/haskell-tf-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
